changeset 7694:c818925b8298

* lib/regcomp.c (parse_branch): Rename local, exp->expr, to avoid warning from "gcc -Wshadow" about shadowing the builtin.
author Jim Meyering <jim@meyering.net>
date Tue, 28 Nov 2006 08:35:51 +0000
parents 52002c9e5fd9
children 648191d7ca53
files ChangeLog lib/regcomp.c
diffstat 2 files changed, 12 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2006-11-28  Jim Meyering  <jim@meyering.net>
+
+	* lib/regcomp.c (parse_branch): Rename local, exp->expr, to avoid
+	warning from "gcc -Wshadow" about shadowing the builtin.
+
 2006-11-27  Bruno Haible  <bruno@clisp.org>
 
 	* m4/stdint.m4 (gl_STDINT_BITSIZEOF): Use AC_COMPUTE_INT instead of
--- a/lib/regcomp.c
+++ b/lib/regcomp.c
@@ -2177,7 +2177,7 @@
 parse_branch (re_string_t *regexp, regex_t *preg, re_token_t *token,
 	      reg_syntax_t syntax, Idx nest, reg_errcode_t *err)
 {
-  bin_tree_t *tree, *exp;
+  bin_tree_t *tree, *expr;
   re_dfa_t *dfa = (re_dfa_t *) preg->buffer;
   tree = parse_expression (regexp, preg, token, syntax, nest, err);
   if (BE (*err != REG_NOERROR && tree == NULL, 0))
@@ -2186,14 +2186,14 @@
   while (token->type != OP_ALT && token->type != END_OF_RE
 	 && (nest == 0 || token->type != OP_CLOSE_SUBEXP))
     {
-      exp = parse_expression (regexp, preg, token, syntax, nest, err);
-      if (BE (*err != REG_NOERROR && exp == NULL, 0))
+      expr = parse_expression (regexp, preg, token, syntax, nest, err);
+      if (BE (*err != REG_NOERROR && expr == NULL, 0))
 	{
 	  return NULL;
 	}
-      if (tree != NULL && exp != NULL)
+      if (tree != NULL && expr != NULL)
 	{
-	  tree = create_tree (dfa, tree, exp, CONCAT);
+	  tree = create_tree (dfa, tree, expr, CONCAT);
 	  if (tree == NULL)
 	    {
 	      *err = REG_ESPACE;
@@ -2201,8 +2201,8 @@
 	    }
 	}
       else if (tree == NULL)
-	tree = exp;
-      /* Otherwise exp == NULL, we don't need to create new tree.  */
+	tree = expr;
+      /* Otherwise expr == NULL, we don't need to create new tree.  */
     }
   return tree;
 }